from .locales import *
from .funcs import *
from .catalog import pack_dictionary, ui_locale_json


def start() -> None:
    pass
